magneticalc.Assert_Dialog.Assert_Dialog

# ``magneticalc`.`Assert_Dialog`.`Assert_Dialog``

class documentation

`class Assert_Dialog:`

Constructor: `Assert_Dialog(assertion, message)`

View In Hierarchy

Assert_Dialog class.

Method | `__init__` | Shows a user dialog if an assertion failed. Intended for beta-testing. This allows the user to either quit or resume (possibly resulting in unstable behaviour). Furthermore, it provides a link for filing an issue on GitHub (partially prefilled).
Instance Variable | `_dialog` | Undocumented

def __init__(self, assertion: `bool`, message: `str`):

Shows a user dialog if an assertion failed. Intended for beta-testing. This allows the user to either quit or resume (possibly resulting in unstable behaviour). Furthermore, it provides a link for filing an issue on GitHub (partially prefilled).

Parameters
assertion: `bool` | Boolean
message: `str` | Error message

_dialog =

Undocumented